﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Controls.Primitives;
using DlhSoft.Windows.Data;

namespace GanttChartTaskListViewBarDrawingSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        // When drawing starts, set up an empty horizontally positioned temporary rectangle as the thumb tag.
        private void DrawThumb_DragStarted(object sender, DragStartedEventArgs e)
        {
            Thumb itemThumb = sender as Thumb;
            if (itemThumb == null)
                return;
            itemThumb.Tag = new Rect(e.HorizontalOffset, 0, 0, itemThumb.ActualHeight);
        }

        // While drawing is in progress, update the width of the thumb tag temporary rectangle.
        private void DrawThumb_DragDelta(object sender, DragDeltaEventArgs e)
        {
            Thumb itemThumb = sender as Thumb;
            if (itemThumb == null || itemThumb.Tag == null || !(itemThumb.Tag is Rect))
                return;
            Rect rect = (Rect)itemThumb.Tag;
            itemThumb.Tag = new Rect(rect.X, Math.Max(e.HorizontalChange, 0), rect.Y, rect.Height);
        }

        // When drawing is completed, set up the start and finish of the data bound task object based on the current temporary rectangle, and remove the thumb tag.
        private void DrawThumb_DragCompleted(object sender, DragCompletedEventArgs e)
        {
            Thumb itemThumb = sender as Thumb;
            if (itemThumb == null || itemThumb.Tag == null || !(itemThumb.Tag is Rect))
                return;
            Rect rect = (Rect)itemThumb.Tag;
            itemThumb.Tag = null;
            Task task = itemThumb.DataContext as Task;
            if (task == null)
                return;
            DateTime start = GanttChartTaskListView.GetDateTime(rect.X);
            DateTime finish = GanttChartTaskListView.GetDateTime(rect.X + rect.Width);
            task.Start = start;
            if (finish > task.Start)
                task.Finish = finish;
        }
    }
}
